MethodChannelVoiceRecognition class

Inheritance

Properties

eventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllLocal() → Future<List<String>>
override
listenResult() → Stream<VoiceRecognitionModel>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLang(String name) → Future
override
startVoice() → Future
override
stopVoice() → Future
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited