VoiceRecognitionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • VoiceRecognitionPlatform
Implementers

Constructors

VoiceRecognitionPlatform()
Constructs a VoiceRecognitionPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllLocal() → Future<List<String>>
listenResult() → Stream<VoiceRecognitionModel>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLang(String name) → Future
startVoice() → Future
stopVoice() → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ VoiceRecognitionPlatform
The default instance of VoiceRecognitionPlatform to use.
getter/setter pair